package plugins;

import engine.*;
import java.util.regex.Pattern;
import java.net.*;
import java.io.*;

public class WrzutaPlugin implements Plugin
{
	private boolean mEnabled;

	public String getName()
	{
		return "Wrzuta";
	}

	public boolean enabled()	
	{
		return mEnabled;
	}

	public void setEnabled(boolean e)
	{
		mEnabled = e;
	}

	public boolean checkLink(String link)
	{
		return Pattern.matches("http://(.*)\\.wrzuta\\.pl/(audio|film)/([a-zA-Z0-9]*)/(.*)", link);
	}

	public boolean initTask(Task task)
	{	
		return true;
	}

	public void cleanTask(Task task)
	{
		
	}

	public String getIcon()
	{
		return "plugins/wrzuta.png";
	}
	
	public boolean allowMoreTasks()
	{
		return true;
	}

	public void run(Task task)
	{
		/* Główna funkcja pluginu, tutaj po prostu pobieramy plik */
		String link = task.getLink();
		link = link.replaceAll("/audio/", "/sr/f/");
		link = link.replaceAll("/film/", "/sr/v/");
		
		try
		{
			URLConnection c = Task.makeConnection(link);
			if (c == null)
			{
				//System.out.println("Blad polaczenia!");
				task.setState(TaskState.tsError, "Błąd połączenia");
				return;
			}

			URL url = c.getURL();
			
			int total = c.getContentLength();
			//System.out.println("total = " + total);
			InputStream input = c.getInputStream();
			// Nazwa pliku z URLa
			FileOutputStream out = new FileOutputStream(task.getDestDir() + File.separator + Task.baseName(url.getPath()));
			byte buf[] = new byte[8192];
			int len;
			int done = 0;

			while((len = input.read(buf)) > 0)
			{
				if (task.getTaskState() != TaskState.tsRunning)
				{	
					input.close();
					out.close();
					return;
				}

				out.write(buf, 0, len);
				done += len;
				task.setProgress(done, total);				
			}

			input.close();
			out.close();
			task.setState(TaskState.tsDone);
		}
		catch (Exception e)
		{
			task.setState(TaskState.tsError, e.getMessage());
		}
		
	}
}
